@@ -14,7 +14,7 @@ uuid=`${tools_dir}/grib_get -w count=1 -p uuidOfVGrid:s ${data_dir}/test_uuid.gr
 [ "$uuid" = "08b1e836bc6911e1951fb51b5624ad8d" ]
 
 # This reads the file in data/test_uuid.grib2 and creates test_uuid.grib2
-${examples_dir}f_get_set_uuid > /dev/null
+${examples_dir}grib_api_f_get_set_uuid > /dev/null
 
 # Check output was written
 output=out_uuid.grib2
