@@ -9,7 +9,7 @@
 
 . ./include.sh
 
-${examples_dir}f_multi_write > /dev/null
+${examples_dir}grib_api_f_multi_write > /dev/null
 
 ${tools_dir}/grib_compare ${data_dir}/multi_created.grib2 multi_created.grib2
 
