@@ -36,9 +36,9 @@ extern "C" {
 #include <math.h>
 
 #if defined( __GNUC__) || defined(__clang__)
-#define DEPRECATED __attribute__((deprecated))
+#define GRIB_API_DEPRECATED __attribute__((deprecated))
 #else
-#define DEPRECATED
+#define GRIB_API_DEPRECATED
 #endif
 
 
@@ -437,6 +437,7 @@ grib_handle* grib_handle_new_from_message(grib_context* c, void* data, size_t da
 *  Create a handle from a user message in memory. The message will not be freed at the end.
 *  The message will be copied as soon as a modification is needed.
 *  This function works also with multi field messages.
+*  Note: The data pointer argument may be modified
 *
 * @param c           : the context from which the handle will be created (NULL for default context)
 * @param data        : the actual message
@@ -467,7 +468,7 @@ grib_handle* grib_handle_new_from_message_copy(grib_context* c, const void* data
 * @param res_name    : the resource name
 * @return            the new handle, NULL if the resource is invalid or a problem is encountered
 */
-DEPRECATED grib_handle* grib_handle_new_from_template (grib_context* c, const char* res_name)  ;
+GRIB_API_DEPRECATED grib_handle* grib_handle_new_from_template (grib_context* c, const char* res_name)  ;
 
 /**
  *  Create a handle from a message contained in a samples directory.
@@ -1389,6 +1390,54 @@ typedef struct grib_util_grid_spec {
 
 } grib_util_grid_spec;
 
+typedef struct grib_util_grid_spec2 {
+
+    int grid_type;
+    const char* grid_name; /* e.g. N320 */
+
+    /* Grid */
+    long   Ni;
+    long   Nj;
+
+    double iDirectionIncrementInDegrees;
+    double jDirectionIncrementInDegrees;
+
+    double longitudeOfFirstGridPointInDegrees;
+    double longitudeOfLastGridPointInDegrees;
+
+    double latitudeOfFirstGridPointInDegrees;
+    double latitudeOfLastGridPointInDegrees;
+
+    /* Rotation */
+    long uvRelativeToGrid;
+    double latitudeOfSouthernPoleInDegrees;
+    double longitudeOfSouthernPoleInDegrees;
+    double angleOfRotationInDegrees;
+
+    /* Scanning mode */
+    long iScansNegatively;
+    long jScansPositively;
+
+    /* Gaussian number */
+    long N;
+
+    /* bitmap */
+    long bitmapPresent;
+    double missingValue;
+
+    /* pl list for reduced */
+    const long *pl;
+    long pl_size;
+
+    /* Spherical harmonics */
+    long truncation;
+
+    /* polar stereographic */
+    double orientationOfTheGridInDegrees;
+    long DyInMetres;
+    long DxInMetres;
+
+} grib_util_grid_spec2;
 
 #define GRIB_UTIL_PACKING_TYPE_SAME_AS_INPUT      0
 #define GRIB_UTIL_PACKING_TYPE_SPECTRAL_COMPLEX 1
@@ -1442,6 +1491,13 @@ grib_handle *grib_util_set_spec(grib_handle *h,
 	size_t data_values_count,
 	int *err);
 
+grib_handle *grib_util_set_spec2(grib_handle *h,
+    const grib_util_grid_spec2   *grid_spec,
+    const grib_util_packing_spec *packing_spec,  /* NULL for defaults (same as input) */
+    int flags,
+    const double *data_values,
+    size_t data_values_count,
+    int *err);
 
 /* --------------------------------------- */
 
